Autogenerated documentation
===========================

These docs are generated by Sphinx from the docstrings in ``django-mptt``.

They're not necessarily very helpful. You might be just as well off reading the `source code`_.

.. toctree::
   :maxdepth: 3

   mptt

.. _`source code`: https://github.com/django-mptt/django-mptt/
